#
# Configure paths and flags for the TvlSim library.
# Denis Arnaud <denis_arnaud at users dot sourceforge dot net>, July 2008
#
# Note: the TVLSIM library depends upon BOOST to build.
# Your configure.ac must therefore define appropriately the BOOST
# variables (i.e., BOOST_CFLAGS, BOOST_LIBS, BOOST_DATE_TIME_LIB).
#
# Variables set by this macro:
#  * TVLSIM_VERSION
#  * TVLSIM_CFLAGS
#  * TVLSIM_LIBS
#  * TVLSIM_SAMPLE_DIR
#

AC_DEFUN([AM_PATH_TVLSIM],
[
AC_LANG_SAVE
AC_LANG([C++])

##
AC_ARG_WITH(tvlsim,
	[ --with-tvlsim=PFX Prefix where TvlSim is installed (optional) ],
	    tvlsim_dir="$withval",
	    tvlsim_dir="")

  if test "x${TVLSIM_CONFIG+set}" != xset ; then
     if test "x$tvlsim_dir" != x ; then
         TVLSIM_CONFIG="$tvlsim_dir/bin/tvlsim-config"
     fi
  fi

  AC_PATH_PROG(TVLSIM_CONFIG, tvlsim-config, no)

  ## Check whether Boost flags and libraries are defined
  # General Boost compilation flags
  AC_MSG_CHECKING(for BOOST_CFLAGS environment variable)
  if test x"${BOOST_CFLAGS}" = x; then
	AC_MSG_RESULT([Warning: TvlSim needs Boost, and the BOOST_CFLAGS environment variable does not appear to be set. It may not be a problem, though, if your Unix distribution is standard, that is, if Boost is installed in /usr. Otherwise, the TvlSim will fail to compile.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_CFLAGS})])
  fi

  # Boost Date-Time library
  AC_MSG_CHECKING(for BOOST_DATE_TIME_LIB environment variable)
  if test x"${BOOST_DATE_TIME_LIB}" = x; then
	AC_MSG_RESULT([Warning: TvlSim needs the Boost Date-Time library, and the BOOST_DATE_TIME_LIB environment variable does not appears to be set. The TvlSim may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_DATE_TIME_LIB})])
  fi

  # Boost Program Options library
  AC_MSG_CHECKING(for BOOST_PROGRAM_OPTIONS_LIB environment variable)
  if test x"${BOOST_PROGRAM_OPTIONS_LIB}" = x; then
	AC_MSG_RESULT([Warning: TvlSim needs the Boost Program Options library, and the BOOST_PROGRAM_OPTIONS_LIB environment variable does not appears to be set. The TvlSim may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_PROGRAM_OPTIONS_LIB})])
  fi

  # Boost File System library
  AC_MSG_CHECKING(for BOOST_FILESYSTEM_LIB environment variable)
  if test x"${BOOST_FILESYSTEM_LIB}" = x; then
	AC_MSG_RESULT([Warning: TvlSim needs the Boost Date-Time library, and the BOOST_FILESYSTEM_LIB environment variable does not appears to be set. The TvlSim may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_FILESYSTEM_LIB})])
  fi

  ## TvlSim version
  min_tvlsim_version=ifelse([$1], ,0.1.0,$1)
  AC_MSG_CHECKING(for TvlSim - version >= $min_tvlsim_version)
  no_tvlsim=""
  if test "${TVLSIM_CONFIG}" = "no" ; then
     no_tvlsim=yes
     AC_MSG_RESULT([no])
  else
     TVLSIM_VERSION=`${TVLSIM_CONFIG} --version`
     TVLSIM_CFLAGS=`${TVLSIM_CONFIG} --cflags`
     TVLSIM_CFLAGS="${BOOST_CFLAGS} ${TVLSIM_CFLAGS}"
     TVLSIM_LIBS=`${TVLSIM_CONFIG} --libs`
     TVLSIM_LIBS="${BOOST_LIBS} ${BOOST_DATE_TIME_LIB} ${TVLSIM_LIBS}"
     TVLSIM_SAMPLE_DIR=`${TVLSIM_CONFIG} --sampledir`

     AC_SUBST([TVLSIM_VERSION])
     AC_SUBST([TVLSIM_CFLAGS])
     AC_SUBST([TVLSIM_LIBS])
     AC_SUBST([TVLSIM_SAMPLE_DIR])

    tvlsim_major_version=`echo ${TVLSIM_VERSION} | sed 's/^\([[0-9]]*\).*/\1/'`
    if test "x${tvlsim_major_version}" = "x" ; then
       tvlsim_major_version=0
    fi

    tvlsim_minor_version=`echo ${TVLSIM_VERSION} | \
						sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\2/'`
    if test "x${tvlsim_minor_version}" = "x" ; then
       tvlsim_minor_version=0
    fi

    tvlsim_micro_version=`echo ${TVLSIM_VERSION} | \
          sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\3/'`
    if test "x${tvlsim_micro_version}" = "x" ; then
       tvlsim_micro_version=0
    fi

    ## Simple test of compilation and link
    SAVED_CPPFLAGS="${CPPFLAGS}"
    SAVED_LDFLAGS="${LDFLAGS}"
    CPPFLAGS="${CPPFLAGS} ${BOOST_CFLAGS} ${TVLSIM_CFLAGS}"
    LDFLAGS="${LDFLAGS} ${TVLSIM_LIBS}"


    AC_COMPILE_IFELSE(
		[AC_LANG_PROGRAM([[#include <tvlsim/TVLSIM_Service.hpp>
				]],
				[[int i=0;]]
		)]
		,

    	[AC_MSG_RESULT([yes (${TVLSIM_VERSION})])],

	[AC_MSG_ERROR([We could not compile a simple TvlSim example. See config.log.])]
    )

    CPPFLAGS="${SAVED_CPPFLAGS}"
    LDFLAGS="${SAVED_LDFLAGS}"

  fi

AC_LANG_RESTORE
])
